@@ -58,6 +58,10 @@ class EventStation(EventQueue):
             return self._respond(event)
         return
 
+    def __eq__(self, other):
+        return isinstance(other, EventStation) and self.key == other.key and self._filter == other._filter and self._respond == other._respond \
+               and self.filter == other.filter and self.respond == other.respond
+
     def push(self, event:Event, timeout=1) -> bool:
         """
 
